DartFlutterVersion class abstract
An abstract class providing access to Dart and Flutter SDK version information.
Use the factory constructor to obtain the singleton instance.
- Implementers
Constructors
- DartFlutterVersion()
-
Factory constructor that returns the singleton instance of
DartFlutterVersionImpl.
factory
Properties
- dartVersion → Version?
-
Current Dart SDK
Version, ornullif it cannot be determined.no setter - flutterVersion → Version?
-
The Flutter SDK
Versionthat corresponds to the current dartVersion, ornullif it cannot be determined.no setter - hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited